@@ -71,6 +71,13 @@ from pylav.types import BotT, CogT, ContextT, InteractionT, LavalinkResponseT
 from pylav.utils import PyLavContext, SingletonMethods, _get_context, _process_commands, _Singleton, add_property
 from pylav.vendored import aiopath
 
+try:
+    from redbot.core.i18n import Translator
+
+    _ = Translator("PyLavPlayer", pathlib.Path(__file__))
+except ImportError:
+    _ = lambda x: x
+
 LOGGER = getLogger("PyLav.Client")
 
 
@@ -294,9 +301,7 @@ class Client(metaclass=_Singleton):
         return self._user_id
 
     @SingletonMethods.run_once_async
-    async def initialize(
-        self,
-    ) -> None:  # sourcery no-metrics
+    async def initialize(self) -> None:
         try:
             if not self._initiated:
                 async with self._asyncio_lock:
@@ -313,6 +318,7 @@ class Client(metaclass=_Singleton):
                             LOGGER.debug(
                                 "Existing Spotify tokens found; Using them - %s - %s", client_id, client_secret
                             )
+
                         else:
                             LOGGER.info("PyLav being run from a non Red bot")
                             client_id = None
@@ -321,7 +327,6 @@ class Client(metaclass=_Singleton):
                         await self._update_schema_manager.run_updates()
                         await self._radio_manager.initialize()
                         await self._player_manager.initialize()
-
                         self._config = await self._lib_config_manager.get_config(
                             config_folder=self._config_folder,
                             java_path=JAVA_EXECUTABLE,
@@ -331,10 +336,14 @@ class Client(metaclass=_Singleton):
                             use_bundled_lava_link_external=USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE,
                             use_bundled_pylav_external=USE_BUNDLED_EXTERNAL_PYLAV_NODE,
                         )
-                        if self._config.java_path != JAVA_EXECUTABLE:
-                            if JAVA_EXECUTABLE != "java" and os.path.exists(JAVA_EXECUTABLE):
-                                self._config.java_path = JAVA_EXECUTABLE
-                                await self._config.save()
+
+                        if (
+                            self._config.java_path != JAVA_EXECUTABLE
+                            and JAVA_EXECUTABLE != "java"
+                            and os.path.exists(JAVA_EXECUTABLE)
+                        ):
+                            self._config.java_path = JAVA_EXECUTABLE
+                            await self._config.save()
                         LOGGER.info("Config folder: %s", self._config.config_folder)
                         LOGGER.info("Localtracks folder: %s", self._config.localtrack_folder)
                         auto_update_managed_nodes = self._config.auto_update_managed_nodes
@@ -360,6 +369,7 @@ class Client(metaclass=_Singleton):
                         self._spotify_auth = ClientCredentialsFlow(
                             client_id=self._spotify_client_id, client_secret=self._spotify_client_secret
                         )
+
                         from pylav.localfiles import LocalFile
 
                         await LocalFile.add_root_folder(path=localtrack_folder, create=True)
@@ -371,26 +381,38 @@ class Client(metaclass=_Singleton):
                                 self._node_manager._unmanaged_external_password
                                 and self._node_manager._unmanaged_external_host
                             )
-                        ) and self.enable_managed_node:
+                            and self.enable_managed_node
+                        ):
                             await self._local_node_manager.start(java_path=self._config.java_path)
                         else:
                             self._local_node_manager.ready.set()
                         await self.node_manager.connect_to_all_nodes()
                         await self.node_manager.wait_until_ready()
+                        if (
+                            not (
+                                self._node_manager._unmanaged_external_password
+                                and self._node_manager._unmanaged_external_host
+                            )
+                            and self.enable_managed_node
+                        ):
+                            await self._local_node_manager.wait_until_connected()
                         await self.player_manager.restore_player_states()
                         time_now = datetime.datetime.now(tz=datetime.timezone.utc)
                         if self._config.next_execution_update_bundled_playlists is None:
                             self._config.next_execution_update_bundled_playlists = time_now + datetime.timedelta(
                                 minutes=5
                             )
+
                         if self._config.next_execution_update_bundled_external_playlists is None:
                             self._config.next_execution_update_bundled_external_playlists = (
                                 time_now + datetime.timedelta(minutes=10)
                             )
+
                         if self._config.next_execution_update_external_playlists is None:
                             self._config.next_execution_update_external_playlists = time_now + datetime.timedelta(
                                 minutes=30
                             )
+
                         self._scheduler.add_job(
                             self._query_cache_manager.delete_old,
                             trigger="interval",
@@ -401,6 +423,7 @@ class Client(metaclass=_Singleton):
                             coalesce=True,
                             id=f"{self.bot.user.id}-cache_delete_old",
                         )
+
                         self._scheduler.add_job(
                             self.playlist_db_manager.update_bundled_playlists,
                             trigger="interval",
@@ -413,10 +436,12 @@ class Client(metaclass=_Singleton):
                             id=f"{self.bot.user.id}-update_bundled_playlists",
                             misfire_grace_time=None,
                         )
+
                         LOGGER.info(
                             "Scheduling first run of Bundled Playlist update task to: %s",
                             self._config.next_execution_update_bundled_playlists,
                         )
+
                         self._scheduler.add_job(
                             self.playlist_db_manager.update_bundled_external_playlists,
                             trigger="interval",
@@ -429,10 +454,12 @@ class Client(metaclass=_Singleton):
                             id=f"{self.bot.user.id}-update_bundled_external_playlists",
                             misfire_grace_time=None,
                         )
+
                         LOGGER.info(
                             "Scheduling first run of Bundled External Playlist update task to: %s",
                             self._config.next_execution_update_bundled_external_playlists,
                         )
+
                         self._scheduler.add_job(
                             self.playlist_db_manager.update_external_playlists,
                             trigger="interval",
@@ -445,10 +472,12 @@ class Client(metaclass=_Singleton):
                             id=f"{self.bot.user.id}-update_external_playlists",
                             misfire_grace_time=None,
                         )
+
                         LOGGER.info(
                             "Scheduling first run of External Playlist update task to: %s",
                             self._config.next_execution_update_external_playlists,
                         )
+
                         await self._config.save()
                         self._scheduler.start()
                         self.ready.set()
@@ -571,11 +600,11 @@ class Client(metaclass=_Singleton):
             A dict representing the track's information.
         """
         if not self.node_manager.available_nodes:
-            raise NoNodeAvailable("No available nodes!")
+            raise NoNodeAvailable(_("No available nodes!"))
         node = await self.node_manager.find_best_node(feature=feature)
         if node is None and feature:
             raise NoNodeWithRequestFunctionalityAvailable(
-                f"No node with {feature} functionality available!", feature=feature
+                _("No node with {feature} functionality available!").format(feature=feature), feature=feature
             )
         return await node.decode_track(track)
 
@@ -596,11 +625,11 @@ class Client(metaclass=_Singleton):
             A list of dicts representing track information.
         """
         if not self.node_manager.available_nodes:
-            raise NoNodeAvailable("No available nodes!")
+            raise NoNodeAvailable(_("No available nodes!"))
         node = await self.node_manager.find_best_node(feature=feature)
         if node is None and feature:
             raise NoNodeWithRequestFunctionalityAvailable(
-                f"No node with {feature} functionality available!", feature=feature
+                _("No node with {feature} functionality available!").format(feature=feature), feature=feature
             )
         return await node.decode_tracks(tracks)
 
@@ -883,7 +912,8 @@ class Client(metaclass=_Singleton):
         )
         if node is None:
             raise NoNodeWithRequestFunctionalityAvailable(
-                f"No node with {query.requires_capability} functionality available!", query.requires_capability
+                _("No node with {query.requires_capability} functionality available!").format(query=query),
+                query.requires_capability,
             )
         return await node.get_tracks(query, first=first, bypass_cache=bypass_cache)
 
@@ -1026,7 +1056,6 @@ class Client(metaclass=_Singleton):
             async for m3u in query._yield_m3u_tracks():
                 with contextlib.suppress(Exception):
                     async for q in query._yield_tracks_recursively(m3u, recursion_depth):
-                        LOGGER.warning("Yielding m3u..2. tracks: %s", q.__dict__)
                         yield q
         elif query.is_pylav:
             async for pylav in query._yield_pylav_file_tracks():
@@ -1140,12 +1169,15 @@ class Client(metaclass=_Singleton):
     ) -> str:
         if not await asyncstdlib.any([video_id, playlist_id, channel_id, user_id]):
             raise PyLavInvalidArguments(
-                "To generate a mix playlist a Video, User, Channel or Playlist ID is necessary."
+                _("To generate a mix playlist a Video, User, Channel or Playlist ID is necessary.")
             )
 
         if await asyncstdlib.sum(1 for i in [video_id, playlist_id, channel_id, user_id] if i) > 1:
             raise PyLavInvalidArguments(
-                "To generate a mix playlist a Video, User, Channel or Playlist ID is necessary. However, you provided multiple."
+                _(
+                    "To generate a mix playlist a Video, User, Channel or Playlist ID is necessary. "
+                    "However, you provided multiple."
+                )
             )
 
         if video_id:
